// File: ex_vertical_ray_shooting.cpp

#include <CGAL/basic.h>
#include <CGAL/Arr_walk_along_line_point_location.h>
#include <CGAL/Arr_trapezoid_ric_point_location.h>

#include "arr_inexact_construction_segments.h"
#include "point_location_utils.h"

typedef CGAL::Arr_walk_along_line_point_location<Arrangement>  Walk_pl;
typedef CGAL::Arr_trapezoid_ric_point_location<Arrangement>    Trap_pl;

int main()
{
  // Construct the arrangement.
  Arrangement  arr;
  Walk_pl      walk_pl(arr);
  construct_segments_arr(arr);

  // Perform some vertical ray-shooting queries using the walk strategy.
  shoot_vertical_ray(walk_pl, Point(1, 4));           // q1
  shoot_vertical_ray(walk_pl, Point(4, 3));           // q2
  shoot_vertical_ray(walk_pl, Point(6, 3));           // q3

  // Attach the trapezoidal-RIC object to the arrangement and perform queries.
  Trap_pl trap_pl;  trap_pl.attach(arr);
  shoot_vertical_ray(trap_pl, Point(3, 2));           // q4
  shoot_vertical_ray(trap_pl, Point(5, 2));           // q5
  shoot_vertical_ray(trap_pl, Point(1, 0));           // q6

  return 0;
}
